# biops

biops is a python package for simulating the performance of biological processes. For example, activated sludge and biofilm reactors used in wastewater treatment.

See the documentation at biops.readthedoc.io